@@ -1,5 +1,7 @@
 #!/bin/bash
 
+set -euo pipefail
+
 # ensure git is in the correct branch and has latest from remote.
 git checkout master
 git pull origin master
@@ -7,7 +9,7 @@ git pull origin master
 version=$(cat VERSION)
 echo "version: $version"
 
-# exist if tag already exists.
+# exit if tag already exists.
 if [ $(git tag -l "$version") ]; then
   echo "tag already exists. Ensure version number has been update in VERSION."
   exit 1
@@ -19,7 +21,4 @@ if ! [[ "$version" =~ ^[0-9.]+$ ]]; then
   exit 1
 fi
 
-docker build -t infinityworks/github-exporter:latest -t infinityworks/github-exporter:$version .
-docker push infinityworks/github-exporter:latest
-docker push infinityworks/github-exporter:$version
-
+docker buildx build --platform linux/amd64 -t githubexporter/github-exporter:latest -t githubexporter/github-exporter:$version --push .
